<div align="center">
<img src="_static/logo.svg" alt="zerobench" width="100%">
</div>


# Documentation

[![PyPI version](https://img.shields.io/pypi/v/zerobench?color=%232EBF4F)](https://pypi.org/project/zerobench)
[![Python versions](https://img.shields.io/pypi/pyversions/zerobench.svg?color=%232EBF4F)](https://pypi.org/project/zerobench)

```{include} ../../README.md
---
start-after: "<!-- Start common text with source/index.md -->"
end-before: "<!-- End common text with source/index.md -->"
---
```

## Content

```{toctree}
:maxdepth: 2
:caption: User Guide

user-guide/installation
user-guide/getting-started
user-guide/jax-examples
```

```{toctree}
:maxdepth: 2
:caption: API Reference

api/index
```

```{toctree}
:maxdepth: 1
:caption: Developer Guide

developer-guide
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
